@@ -1 +1,6 @@
 from prsmsp.factories.auth_factory import AuthFactory
+
+
+__all__ = [
+    "AuthFactory",
+]
