@@ -33,7 +33,7 @@ class WebOneSms(ABCSmsPanel):
 
         return Response(status_code, real_response)
 
-    def send_sms(self, receptor: str, message: str, originator: str):
+    def send_sms(self, receptor: str, message: str, originator: str) -> Response:
         """send sms with webone-sms.ir sms panel
 
         :param receptor: reciver of your message
